@@ -2,11 +2,13 @@ from .base_sprite_loader import BaseSpriteLoader
 from .base_deco_sheet import AbstractDecoSheet
 from .base_biome import AbstractBiome, DEFAULT_BASE_PATH
 from .base_floor_sheet import AbstractFloorSheet
+from .base_floorstyled_sheet import AbstractFloorStyledSheet
 
 __all__ = [
     "BaseSpriteLoader",
     "AbstractDecoSheet",
     "AbstractBiome",
     "AbstractFloorSheet",
+    "AbstractFloorStyledSheet",
     "DEFAULT_BASE_PATH",
 ]
