@@ -12,7 +12,7 @@ class QueueHandler(logging.Handler):
         self.log_queue.put(record)
 
 
-def register_queue_handler(queue_handler, log_level):
+def register_queue_handler(queue_handler, log_level=logging.INFO):
     # On linux this handler exists in a subprocess but not on windows.
     for handler in logger.handlers:
         if isinstance(handler, QueueHandler):
