@@ -7,8 +7,8 @@ import zipfile
 from io import BytesIO
 from pathlib import Path
 from shutil import copyfile
-from tkinter import ttk
 from tkinter import font as tk_font
+from tkinter import messagebox, ttk
 
 import requests
 from PIL import Image, ImageTk
@@ -182,7 +182,7 @@ class DownloadFrame(tk.Frame):
 
 def uninstall_playlunky_release(call, tag):
     dest_dir = PLAYLUNKY_DATA_DIR / tag
-    logger.info("Removing version %s from %s", tag, dest_dir)
+    logger.info("Removing Playlunky version %s", tag)
     for file_ in PLAYLUNKY_FILES:
         (dest_dir / file_).unlink(missing_ok=True)
     dest_dir.rmdir()
@@ -273,6 +273,10 @@ class VersionFrame(tk.LabelFrame):
     def show_download_frame(self):
         self.uninstall_frame.grid_forget()
         self.download_frame.grid(row=4, column=0, padx=10, sticky="ew")
+        if not self.selected_var.get():
+            self.download_frame.button["state"] = tk.DISABLED
+        else:
+            self.download_frame.button["state"] = tk.NORMAL
 
     def show_uninstall_frame(self):
         self.download_frame.grid_forget()
@@ -420,6 +424,23 @@ class FiltersFrame(tk.LabelFrame):
             self.parent.master.render_packs()
 
 
+class InstallModFrame(tk.LabelFrame):
+    def __init__(self, parent, *args, **kwargs):
+        super().__init__(parent, text="Install Mod", *args, **kwargs)
+        self.parent = parent
+        self.columnconfigure(0, weight=1)
+        self.rowconfigure(0, weight=1)
+
+        self.button = ttk.Button(self, text="Browse", command=self.install_mod)
+        self.button.grid(row=0, column=0, pady=5, padx=10, sticky="nswe")
+
+    def install_mod(self):
+        tk.messagebox.showinfo(
+            "Coming Soon",
+            "This feature hasn't been implemented yet, but it will be soon!",
+        )
+
+
 class LoadOrderFrame(tk.LabelFrame):
     def __init__(self, parent, *args, **kwargs):
         super().__init__(parent, text="Load Order", *args, **kwargs)
@@ -529,7 +550,9 @@ class LoadOrderFrame(tk.LabelFrame):
 
 
 def launch_playlunky(_call, install_dir, exe_path):
-    logger.info("Executing Playlunky Launcher from %s in %s", exe_path, install_dir)
+    logger.info(
+        "Executing Playlunky Launcher with %s", exe_path.relative_to(PLAYLUNKY_DATA_DIR)
+    )
     working_dir = exe_path.parent
     cmd = [f"{exe_path}", f"--exe_dir={install_dir}"]
     proc = subprocess.Popen(cmd, cwd=working_dir)
@@ -560,20 +583,25 @@ class PlayTab(Tab):
         self.columnconfigure(0, weight=1)
         self.columnconfigure(1, minsize=250)
 
-        self.packs_wrapper = tk.Frame(self)
-        self.packs_wrapper.grid(row=0, column=0, rowspan=3, sticky="nswe")
-        self.packs_wrapper.columnconfigure(0, weight=1)
-        self.packs_wrapper.rowconfigure(1, weight=1)
+        self.play_wrapper = tk.Frame(self)
+        self.play_wrapper.grid(row=0, column=0, rowspan=3, sticky="nswe")
+        self.play_wrapper.columnconfigure(0, weight=1)
+        self.play_wrapper.rowconfigure(1, weight=1)
 
-        self.filter_frame = FiltersFrame(self.packs_wrapper)
+        self.filter_frame = FiltersFrame(self.play_wrapper)
         self.filter_frame.grid(row=0, column=0, pady=5, padx=5, sticky="nswe")
 
+        self.install_mod_frame = InstallModFrame(self.play_wrapper)
+        self.install_mod_frame.grid(row=0, column=1, pady=5, padx=5, sticky="nswe")
+
         self.packs_frame = ScrollableFrame(
-            self.packs_wrapper, text="Select Mods to Play"
+            self.play_wrapper, text="Select Mods to Play"
         )
         self.packs_frame.rowconfigure(0, weight=1)
         self.packs_frame.columnconfigure(0, weight=1)
-        self.packs_frame.grid(row=1, column=0, pady=5, padx=5, sticky="nswe")
+        self.packs_frame.grid(
+            row=1, column=0, columnspan=2, pady=5, padx=5, sticky="nswe"
+        )
 
         self.version_frame = VersionFrame(self, config, task_manager)
         self.version_frame.grid(row=0, column=1, pady=5, padx=5, sticky="nswe")
@@ -794,7 +822,7 @@ class PlayTab(Tab):
 
         for pack in packs_removed:
             (_, item) = self.checkboxes[pack]
-            item.detroy()
+            item.destroy()
             del self.checkboxes[pack]
 
         self.packs = packs
